@@ -35,7 +35,7 @@ typedef struct {
 
 // FIXME: split into two different impl.: GstElement *setup_pipeline (const char *sinkname);
 gboolean pads_compatible (GstPad *pad1, GstPad *pad2);
-gboolean transition_pipeline (GstElement *pipeline, GstState state);
+gboolean transition_pipeline (GstElement *pipeline, GstState state, GstClockTime timeout);
 void     transcode_cache (gpointer id, DAAPRecord *record, db_dir_and_target_transcode_mimetype_t* df);
 
 #endif
